Class: IntegrationApi::MdQuoteItemVO

Inherits:
Object
  • Object
show all
Defined in:
lib/integration_api/models/md_quote_item_vo.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MdQuoteItemVO

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 111

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'ask')
    self.ask = attributes[:'ask']
  end

  if attributes.has_key?(:'ask_size')
    self.ask_size = attributes[:'ask_size']
  end

  if attributes.has_key?(:'bid')
    self.bid = attributes[:'bid']
  end

  if attributes.has_key?(:'bid_size')
    self.bid_size = attributes[:'bid_size']
  end

  if attributes.has_key?(:'change')
    self.change = attributes[:'change']
  end

  if attributes.has_key?(:'close')
    self.close = attributes[:'close']
  end

  if attributes.has_key?(:'currency_code')
    self.currency_code = attributes[:'currency_code']
  end

  if attributes.has_key?(:'day_range')
    self.day_range = attributes[:'day_range']
  end

  if attributes.has_key?(:'exchange')
    self.exchange = attributes[:'exchange']
  end

  if attributes.has_key?(:'high')
    self.high = attributes[:'high']
  end

  if attributes.has_key?(:'last_trade')
    self.last_trade = attributes[:'last_trade']
  end

  if attributes.has_key?(:'last_trade_time_stamp')
    self.last_trade_time_stamp = attributes[:'last_trade_time_stamp']
  end

  if attributes.has_key?(:'low')
    self.low = attributes[:'low']
  end

  if attributes.has_key?(:'market_cap')
    self.market_cap = attributes[:'market_cap']
  end

  if attributes.has_key?(:'nucleus_security_id')
    self.nucleus_security_id = attributes[:'nucleus_security_id']
  end

  if attributes.has_key?(:'open')
    self.open = attributes[:'open']
  end

  if attributes.has_key?(:'prev_close')
    self.prev_close = attributes[:'prev_close']
  end

  if attributes.has_key?(:'ticker')
    self.ticker = attributes[:'ticker']
  end

  if attributes.has_key?(:'volume')
    self.volume = attributes[:'volume']
  end

  if attributes.has_key?(:'year_range')
    self.year_range = attributes[:'year_range']
  end
end

Instance Attribute Details

#ask ⇒ Object

Returns the value of attribute ask.



17
18
19
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 17

def ask
  @ask
end

#ask_size ⇒ Object

Returns the value of attribute ask_size.



19
20
21
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 19

def ask_size
  @ask_size
end

#bid ⇒ Object

Returns the value of attribute bid.



21
22
23
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 21

def bid
  @bid
end

#bid_size ⇒ Object

Returns the value of attribute bid_size.



23
24
25
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 23

def bid_size
  @bid_size
end

#change ⇒ Object

Returns the value of attribute change.



25
26
27
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 25

def change
  @change
end

#close ⇒ Object

Returns the value of attribute close.



27
28
29
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 27

def close
  @close
end

#currency_code ⇒ Object

Returns the value of attribute currency_code.



29
30
31
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 29

def currency_code
  @currency_code
end

#day_range ⇒ Object

Returns the value of attribute day_range.



31
32
33
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 31

def day_range
  @day_range
end

#exchange ⇒ Object

Returns the value of attribute exchange.



33
34
35
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 33

def exchange
  @exchange
end

#high ⇒ Object

Returns the value of attribute high.



35
36
37
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 35

def high
  @high
end

#last_trade ⇒ Object

Returns the value of attribute last_trade.



37
38
39
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 37

def last_trade
  @last_trade
end

#last_trade_time_stamp ⇒ Object

Returns the value of attribute last_trade_time_stamp.



39
40
41
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 39

def last_trade_time_stamp
  @last_trade_time_stamp
end

#low ⇒ Object

Returns the value of attribute low.



41
42
43
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 41

def low
  @low
end

#market_cap ⇒ Object

Returns the value of attribute market_cap.



43
44
45
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 43

def market_cap
  @market_cap
end

#nucleus_security_id ⇒ Object

Returns the value of attribute nucleus_security_id.



45
46
47
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 45

def nucleus_security_id
  @nucleus_security_id
end

#open ⇒ Object

Returns the value of attribute open.



47
48
49
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 47

def open
  @open
end

#prev_close ⇒ Object

Returns the value of attribute prev_close.



49
50
51
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 49

def prev_close
  @prev_close
end

#ticker ⇒ Object

Returns the value of attribute ticker.



51
52
53
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 51

def ticker
  @ticker
end

#volume ⇒ Object

Returns the value of attribute volume.



53
54
55
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 53

def volume
  @volume
end

#year_range ⇒ Object

Returns the value of attribute year_range.



55
56
57
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 55

def year_range
  @year_range
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 58

def self.attribute_map
  {
    :'ask' => :'ask',
    :'ask_size' => :'ask_size',
    :'bid' => :'bid',
    :'bid_size' => :'bid_size',
    :'change' => :'change',
    :'close' => :'close',
    :'currency_code' => :'currency_code',
    :'day_range' => :'day_range',
    :'exchange' => :'exchange',
    :'high' => :'high',
    :'last_trade' => :'last_trade',
    :'last_trade_time_stamp' => :'last_trade_time_stamp',
    :'low' => :'low',
    :'market_cap' => :'market_cap',
    :'nucleus_security_id' => :'nucleus_security_id',
    :'open' => :'open',
    :'prev_close' => :'prev_close',
    :'ticker' => :'ticker',
    :'volume' => :'volume',
    :'year_range' => :'year_range'
  }
end

.swagger_types ⇒ Object

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 84

def self.swagger_types
  {
    :'ask' => :'Float',
    :'ask_size' => :'Integer',
    :'bid' => :'Float',
    :'bid_size' => :'Integer',
    :'change' => :'Float',
    :'close' => :'Float',
    :'currency_code' => :'String',
    :'day_range' => :'String',
    :'exchange' => :'String',
    :'high' => :'Float',
    :'last_trade' => :'Float',
    :'last_trade_time_stamp' => :'DateTime',
    :'low' => :'Float',
    :'market_cap' => :'String',
    :'nucleus_security_id' => :'String',
    :'open' => :'Float',
    :'prev_close' => :'Float',
    :'ticker' => :'String',
    :'volume' => :'Integer',
    :'year_range' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 213

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ask == o.ask &&
      ask_size == o.ask_size &&
      bid == o.bid &&
      bid_size == o.bid_size &&
      change == o.change &&
      close == o.close &&
      currency_code == o.currency_code &&
      day_range == o.day_range &&
      exchange == o.exchange &&
      high == o.high &&
      last_trade == o.last_trade &&
      last_trade_time_stamp == o.last_trade_time_stamp &&
      low == o.low &&
      market_cap == o.market_cap &&
      nucleus_security_id == o.nucleus_security_id &&
      open == o.open &&
      prev_close == o.prev_close &&
      ticker == o.ticker &&
      volume == o.volume &&
      year_range == o.year_range
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 273

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    value
  when :Date
    value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = IntegrationApi.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 337

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 253

def build_from_hash(attributes)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


240
241
242
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 240

def eql?(o)
  self == o
end

#hash ⇒ Fixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum) —

    Hash code



246
247
248
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 246

def hash
  [ask, ask_size, bid, bid_size, change, close, currency_code, day_range, exchange, high, last_trade, last_trade_time_stamp, low, market_cap, nucleus_security_id, open, prev_close, ticker, volume, year_range].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



200
201
202
203
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 200

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



318
319
320
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 318

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



324
325
326
327
328
329
330
331
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 324

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns String presentation of the object.

Returns:

  • (String) —

    String presentation of the object



312
313
314
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 312

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



207
208
209
# File 'lib/integration_api/models/md_quote_item_vo.rb', line 207

def valid?
  true
end